# 🚀 programmering.no | 🤓 matematikk.as
# - Regn ut summen av to tall

# Input
a = input("Tall 1: ")
b = input("Tall 2: ")

# Sum-funksjon for to tall
def to_tall_sum(a, b):

    # Regn ut summen
    c = float(a) + float(b)

    return c

# Sum
c = to_tall_sum(a, b)

# Print
print(f"Summen er: {a} + {b} = {c}")
