# 🚀 programmering.no | 🤓 matematikk.as
# - Eksempel på range (intervall) med steg

# Variabler
intervall = range(4, 20, 2) # Husk 20 + 1 hvis øvre grense skal inkluderes

# For-løkken hopper 2 steg for hver iterasjon
for tall in intervall:
    print(tall)
