# 🚀 programmering.no | 🤓 matematikk.as
# - Kopier liste med copy()

# Verdier
liste = ["A", "B", "C"]

# Kopier liste
liste_copy = liste.copy()

# Print
print(f"Original liste : {liste}")
print(f"Kopiert liste  : {liste_copy}")
