# 🚀 programmering.no | 🤓 matematikk.as
# - Hvordan bruke indeks for å få tak i en bokstav (char) med for-løkke

# Variabler
pyt = "Python 🐍"

# For hver iterasjon printes neste bokstav (char)
for i in range(len(pyt)):
    print(pyt[i])
