# 🚀 programmering.no | 🤓 matematikk.as
# - Sletter alle elementene i en liste

# Verdier
liste = ["Juni", "Juli", "August"]

# Print
print(f"Liste: {liste}")

# Slett alle el i listen
liste = []

# Print
print(f"Liste: {liste}")
